Usage — Galaxy History Evaluator 2.0.0 documentation

# Usage

Galaxy History Evaluator can be used via command-line

    $ ghevaluator --help
    usage: ghevaluator [-h] -u HISTORY_URL -w WORKFLOW_URL -a APIKEY [-o OUTPUT]

    Compare a Galaxy history to a template workflow and generate the JSON and HTML report files

    options:
    -h, --help            show this help message and exit
    -u HISTORY_URL, --history_url HISTORY_URL
                            URL to Galaxy history
    -w WORKFLOW_URL, --workflow_url WORKFLOW_URL
                            URL to template workflow
    -a APIKEY, --apikey APIKEY
                            Galaxy API key
    -o OUTPUT, --output OUTPUT
                            Path to output report

This tool needs then 4 inputs:

1. URL to history to be evaluated

   > To get the URL, you need to publish your history and get the Share Link URL as explained in a dedicated tutorail

   > For example you can use: https://usegalaxy.eu/u/siyu_chen/h/assemblyhands-onsiyu-chen

2. URL to the reference workflow

   > To get the link, you can apply the same approach as for history but for workflow. You can also find link to reference workflow for tutorial directly in tutorial pages, you need to go on the Galaxy Training website: https://training.galaxyproject.org/, and then find the corresponding tutorial to your history.

   > For example, you can use: https://usegalaxy.eu/training-material/topics/assembly/tutorials/general-introduction/workflows/assembly-general-introduction.ga

3. Galaxy API Key for the Galaxy server where the history is available

   > To get your own Galaxy API key, please follow the instructions here

4. Path to where the report file should be created

## Output

The tool will generated a JSON file that will look like:

    TO FILL